Package 'fgc'

Title: FinBIF geographic data conversion
Description: Convert FinBIF data into geographic formats.
Authors: Finnish Museum of Natural History - Luomus [cph], William K. Morris [aut, cre] (ORCID: <https://orcid.org/0000-0002-8686-4154>)
Maintainer: William K. Morris <[email protected]>
License: MIT + file LICENSE
Version: 0.3.29.9000
Built: 2026-05-17 09:20:44 UTC
Source: https://github.com/luomus/finbif-geo-convert

Help Index


FinBIF geo-conversion

Description

Convert FinBIF data to geographic formats.

Usage

finbif_geo_convert(
  input,
  output = "none",
  geo = c("point", "bbox", "footprint"),
  crs = "wgs84",
  dwc = TRUE,
  ...
)

Arguments

input

Character or Integer. Either the path to a Zip archive or tabular data file that has been downloaded from "laji.fi", a URI linking to such a data file (e.g., https://tun.fi/HBF.53254) or an integer representing the URI (i.e., 53254).

output

Character. One of "gpkg" or "none" (default) to prevent writing output to a file.

geo

Character. Geometry of output. One of "point", "bbox" or " "footprint".

crs

Character or Integer. Coordinate reference system of output. One of "euref" or "wgs84".

dwc

Logical. Use Darwin Core (or Darwin Core style) variable names.

...

Other options passed to finbif::finbif_occurrence_load.

Value

An {sf} package simple feature object (invisibly). And if output != "none" then the spatial data file(s) will be written to the current working directory.


Read error message

Description

Read a formatted error msg.

Usage

read_error_msg(err)

Arguments

err

Error to format.

Value

A list.


Sanitise input ID

Description

Convert FinBIF download identifier inputs of different types

Usage

sanitise_id(x)

Arguments

x

A FinBIF download identifier

Value

A sanitised FinBIF download identifier